@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Pod::Simple::SimpleTree;
 use Pandoc::Elements;
@@ -18,7 +18,6 @@ sub _parser {
 
     my $parser = Pod::Simple::SimpleTree->new;
     $parser->nix_X_codes(1);         # ignore X<...> codes
-    $parser->parse_empty_lists(0);   # ignore empty lists
     $parser->nbsp_for_S(1);          # map S<...> to U+00A0 (non-breaking space)
     $parser->merge_text(1);          # emit text nodes combined
     $parser->no_errata_section(1);   # omit errata section
@@ -47,7 +46,7 @@ sub parse_file {
 
 sub parse_string {
     my ( $self, $string ) = @_;
-    $self->parse_tree( $self->_parser->parse_content($string)->root );
+    $self->parse_tree( $self->_parser->parse_string_document($string)->root );
 }
 
 sub parse_tree {
@@ -123,7 +122,7 @@ sub _pod_element {
 sub _pod_content {
     my ($element) = @_;
     my $length = scalar @$element;
-    map { _pod_element($_) } @$element[ 2 .. ($length - 1) ];
+    map { _pod_element($_) } @$element[ 2 .. ( $length - 1 ) ];
 }
 
 # stringify the content of an element
@@ -191,13 +190,14 @@ sub _pod_data {
 
     my $length = scalar @$element;
     my $content = join "\n\n", map { $_->[2] }
-    grep { $_->[0] eq 'Data' } @$element[ 2 .. $length - 1 ];
+      grep { $_->[0] eq 'Data' } @$element[ 2 .. $length - 1 ];
 
     if ( $target eq 'html' ) {
         $content = "<div>$content</div>" if $content !~ /^<.+>$/s;
-        RawBlock 'html', $content."\n";
+        RawBlock 'html', $content . "\n";
     }
     elsif ( $target =~ /^(la)?tex$/ ) {
+
         # TODO: more intelligent check & grouping, especiall at the end
         $content = "\\begingroup $content \\endgroup" if $content !~ /^[\\{]/;
         RawBlock 'tex', "$content\n";
@@ -249,7 +249,6 @@ sub _pod_list {
     return @list;
 }
 
-
 1;
 __END__
 
